# we use the upstream version from http_parser.h as the SONAME
%define somajor 2
%define sominor 0

%define libname %mklibname %{name} %{somajor}
%define devname %mklibname -d %{name}

Name:           http-parser
Version:        2.9.4
%define subrel 1
Release:        %mkrel 1
Summary:        HTTP request/response parser for C
Group:          System/Libraries
License:        MIT
URL:            http://github.com/joyent/http-parser
Source0:	https://github.com/joyent/http-parser/archive/v%{version}/%{name}-%{version}.tar.gz
# https://github.com/nodejs/http-parser/pull/483
Patch0001:      0001-url-treat-empty-port-as-default.patch
# Build shared library with SONAME using gyp and remove -O flags so optflags take over
# TODO: do this nicely upstream
Patch10:		http-parser-gyp-sharedlib.patch
Patch11:		CVE-2020-8287.patch
BuildRequires:	gyp

%description
This is a parser for HTTP messages written in C. It parses both requests and
responses. The parser is designed to be used in performance HTTP applications.
It does not make any syscalls nor allocations, it does not buffer data, it can
be interrupted at anytime. Depending on your architecture, it only requires
about 40 bytes of data per message stream (in a web server that is per
connection).

%package -n %{libname}
Summary:	A parser for HTTP messages written in C
Group:		System/Libraries
# Do this provide as a temp fix for nodejs
Provides:	http-parser = %{version}-%{release}

%description -n %{libname}
This is a parser for HTTP messages written in C. It parses both requests and
responses. The parser is designed to be used in performance HTTP applications.
It does not make any syscalls nor allocations, it does not buffer data, it can
be interrupted at anytime. Depending on your architecture, it only requires
about 40 bytes of data per message stream (in a web server that is per
connection).

%package -n %{devname}
Group:		Development/C
Summary:	Development headers and libraries for http-parser
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{devname}
Development headers and libraries for http-parser.

%prep
%autosetup -p1
%ifarch %{arm}
# https://github.com/nodejs/http-parser/issues/507
sed -i -e "/sizeof(http_parser)/d" test.c
%endif

%build
# TODO: fix -fPIC upstream
export CFLAGS='%{optflags} -fPIC'
gyp -f make --depth=`pwd` http_parser.gyp
%make_build BUILDTYPE=Release

%install
install -d %{buildroot}%{_includedir}
install -d %{buildroot}%{_libdir}

install -pm644 http_parser.h %{buildroot}%{_includedir}

#install regular variant
install out/Release/lib.target/libhttp_parser.so.%{somajor} %{buildroot}%{_libdir}/libhttp_parser.so.%{somajor}.%{sominor}
ln -sf libhttp_parser.so.%{somajor}.%{sominor} %{buildroot}%{_libdir}/libhttp_parser.so.%{somajor}
ln -sf libhttp_parser.so.%{somajor}.%{sominor} %{buildroot}%{_libdir}/libhttp_parser.so

#install strict variant
install out/Release/lib.target/libhttp_parser_strict.so.%{somajor} %{buildroot}%{_libdir}/libhttp_parser_strict.so.%{somajor}.%{sominor}
ln -sf libhttp_parser_strict.so.%{somajor}.%{sominor} %{buildroot}%{_libdir}/libhttp_parser_strict.so.%{somajor}
ln -sf libhttp_parser_strict.so.%{somajor}.%{sominor} %{buildroot}%{_libdir}/libhttp_parser_strict.so

%check
export LD_LIBRARY_PATH='./out/Release/lib.target'
./out/Release/test-nonstrict
./out/Release/test-strict

%files -n %{libname}
%doc AUTHORS 
%{_libdir}/libhttp_parser.so.%{somajor}
%{_libdir}/libhttp_parser.so.%{somajor}.*
%{_libdir}/libhttp_parser_strict.so.%{somajor}
%{_libdir}/libhttp_parser_strict.so.%{somajor}.*

%files -n %{devname}
%{_includedir}/*
%{_libdir}/libhttp_parser.so
%{_libdir}/libhttp_parser_strict.so


%changelog
* Wed Oct 19 2022 ns80 <ns80> 2.9.4-1.1.mga8
+ Revision: 1897574
- port patch from Debian for CVE-2020-8287 (mga#30740)

* Mon May 11 2020 tv <tv> 2.9.4-1.mga8
+ Revision: 1582885
- 2.9.4

* Wed Mar 04 2020 kekepower <kekepower> 2.9.3-1.mga8
+ Revision: 1553822
- Update to version 2.9.3 (mga#26293)

* Sat Feb 15 2020 umeabot <umeabot> 2.9.2-3.mga8
+ Revision: 1526042
- Mageia 8 Mass Rebuild

* Mon Apr 22 2019 kekepower <kekepower> 2.9.2-2.mga7
+ Revision: 1394637
- Provide http-parser

* Sun Apr 21 2019 kekepower <kekepower> 2.9.2-1.mga7
+ Revision: 1394210
- Update to version 2.9.2

* Sun Sep 23 2018 umeabot <umeabot> 2.7.1-2.mga7
+ Revision: 1298219
- Mageia 7 Mass Rebuild

* Wed Jul 26 2017 neoclust <neoclust> 2.7.1-1.mga7
+ Revision: 1131297
- New version 2.7.1

* Thu Feb 04 2016 umeabot <umeabot> 2.2.1-4.mga6
+ Revision: 935938
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 2.2.1-3.mga5
+ Revision: 747552
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.2.1-2.mga5
+ Revision: 680193
- Mageia 5 Mass Rebuild

* Tue Feb 04 2014 wally <wally> 2.2.1-1.mga5
+ Revision: 582060
- new version 2.2.1
- clean .spec a bit

* Fri Jan 10 2014 tv <tv> 2.0-1.20121128gitcd01361.mga4
+ Revision: 566124
- imported package http-parser


* Fri Jan 10 2014 Thierry Vignaud <tv@mageia.org> 2.0-1.20121128gitcd01361.mga4
- initial release (based on FC)
